/* test-nongui.c
 * This file is part of Vara digital painting program
 * Copyright 2021, 2023, 2024 Nandakumar Edamana
 * Distributed under GNU General Public License, version 3
 */ 

#include <assert.h>
#include <stdarg.h>
#include <stdbool.h>

#include "test-nongui.h"


void test_nongui_memleak_draw(int count)
{
	int i;
	printf("test memory leak: %d x draw in ImageDocument\n", count);
	ImageDocument *doc = (ImageDocument *) malloc(sizeof(ImageDocument));
	if(doc == NULL) {
		perror(NULL);
		exit(EXIT_FAILURE);
	}

	image_document_construct(doc, 16, 16, default_drawparams(), true);
	for(i = 0; i < count; i += 1) {
		doc->drawparams.active_tool = TOOL_FLOODFILL;
		struct LinearPixel _tmp_2;
		if(i % 2) {
			_tmp_2 = LINEAR_PIXEL_BLACK;
		} else {
			_tmp_2 = LINEAR_PIXEL_RED;
		}

		doc->drawparams.fgcolor = _tmp_2;
		image_document_floodfill(doc, 0, 0);
	}

	if(doc) {
		image_document_destruct(doc);
		free(doc);
	}
}

void test_nongui_memleak_imgdoc(int count)
{
	int i;
	printf("test memory leak: %d x new ImageDocument\n", count);
	for(i = 0; i < count; i += 1) {
		ImageDocument *doc = (ImageDocument *) malloc(sizeof(ImageDocument));
		if(doc == NULL) {
			perror(NULL);
			exit(EXIT_FAILURE);
		}

		image_document_construct(doc, 2480, 3508, default_drawparams(), true);
		if(doc) {
			image_document_destruct(doc);
			free(doc);
		}
	}
}

void test_nongui_memleak_writexcf(int count)
{
	int i;
	printf("test memory leak: %d x write an xcf image\n", count);
	for(i = 0; i < count; i += 1) {
		ImageDocument *_ngg_tmp_1 = (ImageDocument *) malloc(sizeof(ImageDocument));
		if(_ngg_tmp_1 == NULL) {
			perror(NULL);
			exit(EXIT_FAILURE);
		}

		image_document_construct(_ngg_tmp_1, 64, 64, default_drawparams(), true);
		assert(0 == write_xcf_from_image_document("/tmp/vara-test-xcf-memleak.xcf", _ngg_tmp_1)); /* test-nongui.ngg:26 */
		if(_ngg_tmp_1) {
			image_document_destruct(_ngg_tmp_1);
			free(_ngg_tmp_1);
		}
	}
}

int testmain_nongui(int count)
{
	test_nongui_memleak_imgdoc(count);
	test_nongui_memleak_draw(count);
	test_nongui_memleak_writexcf(count);

	return 0;
}
